@@ -80,14 +80,14 @@ class KubernetesJobOperator(KubernetesJobOperatorDefaultsBase):
                         command, arguments, image, envs, body, namespace, config_file, cluster_context
 
         Auto completed yaml values (if missing):
-
-            metadata.namespace - current namespace
-            spec.backOffLimit - 0
-            spec.template.spec.restartPolicy - Never
-
-        Added yaml values:
-
-            metadata.finalizers += foregroundDeletion
+            All:
+                metadata.namespace = current namespace
+            Pod:
+                spec.restartPolicy = Never
+            Job:
+                spec.backOffLimit = 0
+                spec.template.spec.restartPolicy = Never
+                metadata.finalizers - [foregroundDeletion]
 
         """
         super().__init__(task_id=task_id, **kwargs)
@@ -107,8 +107,15 @@ class KubernetesJobOperator(KubernetesJobOperatorDefaultsBase):
             "body must either be a yaml string or a dict"
         )
 
-        assert delete_policy in JobRunnerDeletePolicy, ValueError(
-            f"Invalid delete policy. Valid values are: {[str(v) for v in JobRunnerDeletePolicy]}"
+        if isinstance(delete_policy, str):
+            try:
+                delete_policy = JobRunnerDeletePolicy(delete_policy)
+            except Exception:
+                delete_policy = None
+
+        assert delete_policy is not None and isinstance(delete_policy, JobRunnerDeletePolicy), ValueError(
+            f"Invalid delete policy. Valid values are ({JobRunnerDeletePolicy.__module__}.JobRunnerDeletePolicy):"
+            + f" {[str(v) for v in JobRunnerDeletePolicy]}"
         )
 
         assert envs is None or isinstance(envs, dict), ValueError("The env collection must be a dict or None")
